syntax = "proto3";

package spotify.login5.v3.challenges;
option java_package = "com.spotify.login5v3";

import "google/protobuf/duration.proto";

message HashcashChallenge {
    bytes prefix = 1;
    int32 length = 2;
}

message HashcashSolution {
    bytes suffix = 1;
    .google.protobuf.Duration duration = 2;
}
