syntax = "proto2";

package spotify.explicit_content.proto;

option optimize_for = CODE_SIZE;
option java_package = "com.spotify.explicit";

message KeyValuePair {
    required string key = 1;
    required string value = 2;
}

message UserAttributesUpdate {
    repeated KeyValuePair pairs = 1;
}
