syntax = "proto3";

package com.spotify.canvazcache;

import "canvaz-meta.proto";

option optimize_for = CODE_SIZE;
option java_package = "com.spotify.canvaz";

message Artist {
    string uri = 1;
    string name = 2;
    string avatar = 3;
}

message EntityCanvazResponse {
    repeated Canvaz canvases = 1;
    message Canvaz {
        string id = 1;
        string url = 2;
        string file_id = 3;
        canvaz.Type type = 4;
        string entity_uri = 5;
        Artist artist = 6;
        bool explicit = 7;
        string uploaded_by = 8;
        string etag = 9;
        string canvas_uri = 11;
    }

    int64 ttl_in_seconds = 2;
}

message EntityCanvazRequest {
    repeated Entity entities = 1;
    message Entity {
        string entity_uri = 1;
        string etag = 2;
    }
}
