syntax = "proto3";

package com.spotify.canvaz;

option optimize_for = CODE_SIZE;
option java_package = "com.spotify.canvaz";

enum Type {
    IMAGE = 0;
    VIDEO = 1;
    VIDEO_LOOPING = 2;
    VIDEO_LOOPING_RANDOM = 3;
    GIF = 4;
}
