syntax = "proto3";

package spotify.login5.v3.identifiers;
option java_package = "com.spotify.login5v3";

message PhoneNumber {
    string number = 1;
    string iso_country_code = 2;
    string country_calling_code = 3;
}
