syntax = "proto3";

package spotify.login5.v3.credentials;
option java_package = "com.spotify.login5v3";

message StoredCredential {
	string username = 1;
	bytes data = 2;
}

message Password {
	string id = 1;
	string password = 2;
	bytes padding = 3;
}

message FacebookAccessToken {
	string fb_uid = 1;
	string access_token = 2;
}

message OneTimeToken {
	string token = 1;
}

message ParentChildCredential {
	string child_id = 1;
	.spotify.login5.v3.credentials.StoredCredential parent_stored_credential = 2;
}

message AppleSignInCredential {
	string auth_code = 1;
	string redirect_uri = 2;
	string bundle_id = 3;
}
