syntax = "proto2";

package spotify;
option java_package = "com.spotify";

message Subscription {
    optional string uri = 0x1;
    optional int32 expiry = 0x2;
    optional int32 status_code = 0x3;
}

