syntax = "proto3";

package spotify.login5.v3;
option java_package = "com.spotify.login5v3";

message UserInfo {
    enum Gender {
        UNKNOWN = 0;
        MALE = 1;
        FEMALE = 2;
        NEUTRAL = 3;
    }
    string name = 1;
    string email = 2;
    bool email_verified = 3;
    string birthdate = 4;
    .spotify.login5.v3.UserInfo.Gender gender = 5;
    string phone_number = 6;
    bool phone_number_verified = 7;
    bool email_already_registered = 8;
}
