syntax = "proto2";

package spotify.player.proto;

option optimize_for = CODE_SIZE;
option java_package = "com.spotify.context";

message ContextPlayerOptions {
    optional bool shuffling_context = 1;
    optional bool repeating_context = 2;
    optional bool repeating_track = 3;
}

message ContextPlayerOptionOverrides {
    optional bool shuffling_context = 1;
    optional bool repeating_context = 2;
    optional bool repeating_track = 3;
}
